/*******************************************************************************
* File Name: s_miso_pin.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "s_miso_pin.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 s_miso_pin__PORT == 15 && ((s_miso_pin__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: s_miso_pin_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void s_miso_pin_Write(uint8 value) 
{
    uint8 staticBits = (s_miso_pin_DR & (uint8)(~s_miso_pin_MASK));
    s_miso_pin_DR = staticBits | ((uint8)(value << s_miso_pin_SHIFT) & s_miso_pin_MASK);
}


/*******************************************************************************
* Function Name: s_miso_pin_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  s_miso_pin_DM_STRONG     Strong Drive 
*  s_miso_pin_DM_OD_HI      Open Drain, Drives High 
*  s_miso_pin_DM_OD_LO      Open Drain, Drives Low 
*  s_miso_pin_DM_RES_UP     Resistive Pull Up 
*  s_miso_pin_DM_RES_DWN    Resistive Pull Down 
*  s_miso_pin_DM_RES_UPDWN  Resistive Pull Up/Down 
*  s_miso_pin_DM_DIG_HIZ    High Impedance Digital 
*  s_miso_pin_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void s_miso_pin_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(s_miso_pin_0, mode);
}


/*******************************************************************************
* Function Name: s_miso_pin_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro s_miso_pin_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 s_miso_pin_Read(void) 
{
    return (s_miso_pin_PS & s_miso_pin_MASK) >> s_miso_pin_SHIFT;
}


/*******************************************************************************
* Function Name: s_miso_pin_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 s_miso_pin_ReadDataReg(void) 
{
    return (s_miso_pin_DR & s_miso_pin_MASK) >> s_miso_pin_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(s_miso_pin_INTSTAT) 

    /*******************************************************************************
    * Function Name: s_miso_pin_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 s_miso_pin_ClearInterrupt(void) 
    {
        return (s_miso_pin_INTSTAT & s_miso_pin_MASK) >> s_miso_pin_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
