/*******************************************************************************
* File Name: main.c
*
* Version: 1.0
*
* Description:
*  This is source code for example project of the SPI
*  (Master, Slave) components.
*  Parameters used:
*   Mode                0(CPHA ==1, CPOL ==1)
*   Data lines          MOSI+MISO
*   Shift direction     MSB First
*   DataBits:           8 
*   Bit Rate            1Mbit/s
*   Clock source        External 
*
*  SPI communication test using software buffer. 8 bytes are transmitted
*  between SPI Master and SPI Slave.
*  Received data are displayed on LCD. 
*
********************************************************************************
* Copyright 2012, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#include <device.h>
#include <AD7793.h>
#include <Communication.h>


/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  Main function performs following functions:
*   1. Declares cycle counter variable.
*   2. Enables interrupts.
*   3. Starts all used components.
*   3. Writes values to be sent into the SPI Slave's and Master's input buffers.
*   4. Waits for the Slave's SPI Done state generation.
*   5. Displays SPI Master and Slave received data.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void main()
{
    uint8 i = 0u;
    uint8 temp;
    #define BUFFER_SIZE                 (8u)
    // Data buffers
    uint8 txBuffer [BUFFER_SIZE];
    uint8 rxBuffer[BUFFER_SIZE];
    
    // Software buffers use internal interrupt functionality to interact with
    // hardware buffers. Thus global interrupt enable command should be called 
    
    CyGlobalIntEnable;
    
    // We need to start Character LCD, SPI Master
    LCD_Start();
    SPIM_Start();

  
    //Reset AD7793
    AD7793_Reset();
    CyDelay(1000u);
    //write to communication register
    //SPI_Write(datacom_reg_read_id,1);
    
    //check AD7793 & show result on a LCD
    LCD_Position(0u,0u);
    if(AD7793_Init())
	{
        LCD_PrintString("AD7793 OK");
	}
	else
	{
		LCD_PrintString("AD7793 Error");	
	}
    CyDelay(1000u);

    
 
}    


// [] END OF FIL
